@@ -545,18 +545,17 @@ def shear_yx(img, degree1, degree2):
 
 
 def perspective_transform(img, pnts1, pnts2, dst_size, resample=Image.CUBIC, fillcolor='black'):
-    import numpy
     def get_coeffs(pa, pb):
         matrix = []
         for p1, p2 in zip(pa, pb):
             matrix.append([p1[0], p1[1], 1, 0, 0, 0, -p2[0] * p1[0], -p2[0] * p1[1]])
             matrix.append([0, 0, 0, p1[0], p1[1], 1, -p2[1] * p1[0], -p2[1] * p1[1]])
 
-        A = numpy.mat(matrix, dtype=numpy.float)
-        B = numpy.array(pb).reshape(8)
+        A = np.mat(matrix, dtype=np.float)
+        B = np.array(pb).reshape(8)
 
-        res = numpy.dot(numpy.linalg.inv(A.T * A) * A.T, B)
-        return numpy.array(res).reshape(8)
+        res = np.dot(np.linalg.inv(A.T * A) * A.T, B)
+        return np.array(res).reshape(8)
 
     assert isinstance(img, Image.Image)
     coeffs = get_coeffs(pnts2, pnts1)
@@ -675,13 +674,13 @@ def sp_noise(img, amount=0.004):
     coords = [np.random.randint(0, i - 1, int(num_salt))
               for i in img.shape]
     # out[coords] = 1
-    out[coords] = 255
+    out[tuple(coords)] = 255
 
     # Pepper mode
     num_pepper = np.ceil(amount * img.size * (1. - s_vs_p))
     coords = [np.random.randint(0, i - 1, int(num_pepper))
               for i in img.shape]
-    out[coords] = 0
+    out[tuple(coords)] = 0
     img = out
     img = Image.fromarray(img.astype(np.uint8))
     return img
